@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 11322 2018-12-25 06:32:28Z Kevin $
+# $Id: __init__.py 11402 2019-03-26 18:21:13Z Lavender $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,9 +11,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Kevin $ (last)
-# $Date: 2018-12-25 15:32:28 +0900 (週二, 25 十二月 2018) $
-# $Revision: 11322 $
+# $Author: Lavender $ (last)
+# $Date: 2019-03-27 03:21:13 +0900 (週三, 27 三月 2019) $
+# $Revision: 11402 $
 
 from __future__ import print_function
 
@@ -637,7 +637,8 @@ def attachSettings(settingsDict, warns=True, printDetail=True):
     #  Django templates.
     tSettings = {
         'BACKEND': 'django.template.backends.django.DjangoTemplates',
-        'DIRS': [],
+        'DIRS': [os.path.join(settingsDict.get('BASE_DIR', projectPath),
+                              'templates'),],
         'APP_DIRS': True,
         'OPTIONS': {
             'context_processors': [
@@ -693,9 +694,10 @@ def attachSettings(settingsDict, warns=True, printDetail=True):
         warnWithout('INSTALLED_APPS', settingsDict, pluginsDefaults)
 
     update(settingsDict, pluginsDefaults)
-    # django-des
+    # django-des & Iuno.deploy
     ADDING_INSTALLED_APPS = (
         'des',
+        'Iuno.deploy',
     )
     installed = settingsDict['INSTALLED_APPS']
     keys = [k for k in installed if k.startswith('django.contrib')]
