@@ -22,6 +22,7 @@ import platform
 import six
 
 from django.core.management.base import BaseCommand, CommandError
+from django.core.management import get_commands
 from django.template.loader import get_template
 from django.template import Context
 
@@ -39,27 +40,49 @@ class Command(BaseCommand):
     def add_arguments(self, parser):
         parser.add_argument('command', type=str, help="Command")
         parser.add_argument('time', type=str, help="Time")
+        parser.add_argument(
+            '-c', '--commandScript', 
+            action='store_true',
+            help="if command is shellscript. This parameter must be add.")
 
     def handle(self, *args, **options):
         command = options['command']
         time = options['time']
+        commandScript = options['commandScript']
         
         sysStr = platform.system()
         if sysStr == "Linux":
             # create shell
-            jobName = hashlib.md5(
-                    toBytes("%s %s" % (command, time))).hexdigest()
-        
+            if commandScript:
+                hashData = hashlib.md5(
+                        toBytes("%s %s" % (command, time))).hexdigest()
+                        
+                jobName = "%s%s" % (command.split()[0], hashData)
+            else:
+                # 判斷 command
+                if not command.split()[0] in get_commands():
+                    raise ValueError(
+                        "This command not in command list of the project: %s" % 
+                        command)
+                jobName = command.split()[0]
+                command = "python manage.py %s" % command
+                
+            # 跳脫
+            command = command.replace("'", "'\\''")
+                
             temp = get_template("deploy/Cron.sh")
             c = Context({
                 "command": command,
                 "time": time,
                 "jobName": jobName,
-                "projectName": os.environ['APP_NAME'], 
             })
             
             shell = temp.render(c).replace("\r\n", "\n")
             
+            # 不知為何 "'" 被 render 成 "&#39;"，
+            # 因此將所有檔案中的 "&#39;" replace 回來
+            shell = shell.replace("&#39;", "'")
+            
             with open("%s.sh" % jobName, 'w') as f:
                 f.write(shell)
             
@@ -75,7 +98,7 @@ class Command(BaseCommand):
                 
             os.remove("%s.sh" % jobName)
         else:
-            pass
+            logger.info("Only support for Linux.")
 
 
             
