@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: views.py 11339 2019-01-15 14:56:17Z Lavender $
+# $Id: views.py 11348 2019-01-21 18:14:25Z Lavender $
 #
 # Copyright (c) 2018 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2019-01-15 23:56:17 +0900 (週二, 15 一月 2019) $
-# $Revision: 11339 $ 
+# $Date: 2019-01-22 03:14:25 +0900 (週二, 22 一月 2019) $
+# $Revision: 11348 $ 
 
 import json
 import logging
@@ -26,6 +26,7 @@ import requests
 
 from lxml import etree
 from django.shortcuts import render
+from django.contrib.sites.shortcuts import get_current_site
 from django.views.decorators.csrf import csrf_exempt
 from django.utils.decorators import method_decorator
 from django.shortcuts import redirect, get_object_or_404
@@ -38,9 +39,11 @@ from django.http import HttpResponse, Http404
 from django.utils import timezone
 from django.template.loader import get_template
 from django.template import Context
+from django.db.models import Q
 from paypal.express.views import SuccessResponseView
 from oscar.core.loading import get_model, get_class
 from oscar.core.phonenumber import to_python
+from oscar.core.compat import get_user_model
 
 from Iuppiter.Encoding import utf8
 from Iuno.shop import forms
@@ -247,7 +250,28 @@ def sendOrderEmail(order, subjectTemp, htmlTemp, txtTemp):
         else:
             logger.error("Send order email fail: %s" % email)
     except Exception as e:
-        logger.error("Error Send order email: %s" % e)
+        logger.error("Error send order email: %s" % e)
+        
+def sandMessageToAdmin(subject, message):
+    try:
+        if hasattr(settings, 'IUNO_SHOP_SAND_MAIL_ADMINS'):
+            emails = settings.IUNO_SHOP_SAND_MAIL_ADMINS
+        else:
+            User = get_user_model()
+            staff = User.objects.filter(Q(is_staff=True) | Q(is_superuser=True))
+            emails = [u.email for u in staff]
+        
+        if emails:
+            send_mail(
+                subject,
+                message,
+                DynamicEmailConfiguration.objects.get().from_email,
+                emails,
+                fail_silently=False,
+            )
+    except Exception as e:
+        logger.error(
+            "Error send order email: %s, %s, %s" % (str(e), subject, message))
     
 
 def handle_order_status_change(self, order, new_status, note_msg=None):
@@ -1002,7 +1026,10 @@ class ECPayServerReplyView(generic.View):
                 self.basketId = int(self.merchantTradeNo[index + 8:])
 
                 order = Order.objects.get(basket=self.basketId)
-
+                
+                site = get_current_site(request)
+                siteName = site.name
+                
                 if self.rtnCode in ['2030', '3024',]:
                     order.status = settings.OSCAR_ORDER_PROCESSING_STATUS
                 elif self.rtnCode in ['2063', '3018', '2073',]:
@@ -1015,6 +1042,17 @@ class ECPayServerReplyView(generic.View):
                     return HttpResponse("|ErrorMessage")
                 order.save()
                 
+                sandMessageToAdmin(
+                    _("[%(site)s]Logistic order status change") % {
+                        'site': siteName,
+                    },
+                    _("Logistic order %(orderNumber)s"
+                      " has changed to %(status)s") % {
+                        'orderNumber': order.number, 
+                        'status': order.status,
+                    },
+                )
+                
                 hasSettings = hasattr(
                     settings, 'OSCAR_PROCESSING_SEND_EMAIL_STATUS')
                 if (hasSettings and 
